==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QRecursiveMutex_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qmutex.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QRecursiveMutex(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QRecursiveMutex")
    QRecursiveMutex *_ptr = reinterpret_cast<QRecursiveMutex *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QRecursiveMutex()
void __qt_construct_QRecursiveMutex_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRecursiveMutex()")
    Q_UNUSED(__java_arguments)
    QRecursiveMutex *__qt_this = new(__qtjambi_ptr) QRecursiveMutex();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QRecursiveMutex
void __qt_destruct_QRecursiveMutex(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRecursiveMutex")
    reinterpret_cast<QRecursiveMutex*>(ptr)->~QRecursiveMutex();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QRecursiveMutex::QRecursiveMutex()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_initialize_1native__Lio_qt_core_QRecursiveMutex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRecursiveMutex::QRecursiveMutex()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRecursiveMutex_0, sizeof(QRecursiveMutex), typeid(QRecursiveMutex), false, &deleter_QRecursiveMutex, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRecursiveMutex::lock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_lock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::lock()", __qt_this)
        __qt_this->lock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRecursiveMutex::tryLock(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_tryLock_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::tryLock(int)", __qt_this)
        __java_return_value = __qt_this->tryLock(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRecursiveMutex::try_lock()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_try_1lock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::try_lock()", __qt_this)
        __java_return_value = __qt_this->try_lock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRecursiveMutex::unlock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_unlock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::unlock()", __qt_this)
        __qt_this->unlock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QRecursiveMutex(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QRecursiveMutex>("QRecursiveMutex", "io/qt/core/QRecursiveMutex");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QRecursiveMutex, {
        ConstructorInfo(&__qt_construct_QRecursiveMutex_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QRecursiveMutex);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QRecursiveMutex_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qmutex.h>
#include <QtCore/QVariant>
#include <QtCore/qdeadlinetimer.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QRecursiveMutex(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QRecursiveMutex")
    QRecursiveMutex *_ptr = reinterpret_cast<QRecursiveMutex *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QRecursiveMutex()
void __qt_construct_QRecursiveMutex(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRecursiveMutex()")
    Q_UNUSED(__java_arguments)
    QRecursiveMutex *__qt_this = new(__qtjambi_ptr) QRecursiveMutex();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QRecursiveMutex::QRecursiveMutex()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_initialize_1native__Lio_qt_core_QRecursiveMutex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRecursiveMutex::QRecursiveMutex()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRecursiveMutex, sizeof(QRecursiveMutex), typeid(QRecursiveMutex), false, &deleter_QRecursiveMutex, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QRecursiveMutex
void __qt_destruct_QRecursiveMutex(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRecursiveMutex")
    reinterpret_cast<QRecursiveMutex*>(ptr)->~QRecursiveMutex();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QRecursiveMutex::lock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_lock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::lock()", __qt_this)
        __qt_this->lock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRecursiveMutex::tryLock(QDeadlineTimer)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_tryLock_1native_1QDeadlineTimer__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID timer0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::tryLock(QDeadlineTimer)", __qt_this)
        QDeadlineTimer __qt_timer0 = QtJambiAPI::valueReferenceFromNativeId<QDeadlineTimer>(timer0);
        __java_return_value = __qt_this->tryLock(__qt_timer0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRecursiveMutex::tryLock(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_tryLock_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::tryLock(int)", __qt_this)
        __java_return_value = __qt_this->tryLock(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRecursiveMutex::try_lock()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_try_1lock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::try_lock()", __qt_this)
        __java_return_value = __qt_this->try_lock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRecursiveMutex::unlock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QRecursiveMutex_unlock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QRecursiveMutex *__qt_this = QtJambiAPI::objectFromNativeId<QRecursiveMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRecursiveMutex::unlock()", __qt_this)
        __qt_this->unlock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QRecursiveMutex(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QRecursiveMutex>("QRecursiveMutex", "io/qt/core/QRecursiveMutex");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QRecursiveMutex, {
        ConstructorInfo(&__qt_construct_QRecursiveMutex, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QRecursiveMutex);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
